@@ -40,12 +40,23 @@ if (isset($_POST['id_comment'])) {$id_comment=$_POST['id_comment'];} else {$id_c
 if (isset($_POST['id_photo'])) {$id_photo=$_POST['id_photo'];}
 if (isset($_POST['edited'])) {$edited=$_POST['edited'];} else {$edited="NULL";}
 if (isset($_POST['posted'])) {$posted=$_POST['posted'];} else {$posted="NULL";}
-if (isset($_POST['headline'])) {$headline = AddSlashes ($_POST['headline']);} else {$headline="NULL";}
-if (isset($_POST['intro_text'])) {$intro_text=AddSlashes ($_POST['intro_text']);} else {$intro_text="NULL";}
-if (isset($_POST['body_text'])) {$body_text=AddSlashes ($_POST['body_text']);} else {$body_text="NULL";}
+
+if (!get_magic_quotes_gpc())
+   {
+   if (isset($_POST['headline'])) {$headline = AddSlashes ($_POST['headline']);} else {$headline="NULL";}
+   if (isset($_POST['intro_text'])) {$intro_text=AddSlashes ($_POST['intro_text']);} else {$intro_text="NULL";}
+   if (isset($_POST['body_text'])) {$body_text=AddSlashes ($_POST['body_text']);} else {$body_text="NULL";}
+   if (isset($_POST['title'])) {$title=AddSlashes ($_POST['title']);} else {$title="NULL";}
+   } else {
+          if (isset($_POST['headline'])) {$headline=$_POST['headline'];} else {$headline="NULL";}
+          if (isset($_POST['intro_text'])) {$intro_text=$_POST['intro_text'];} else {$intro_text="NULL";}
+          if (isset($_POST['body_text'])) {$body_text=$_POST['body_text'];} else {$body_text="NULL";}
+          if (isset($_POST['title'])) {$title=$_POST['title'];} else {$title="NULL";}
+          }
+
 if (isset($_POST['text_type'])) {$text_type=($_POST['text_type']);} else {$text_type="text";}
 if ($text_type=="text"){$body_text=nl2br($body_text);}
-if (isset($_POST['title'])) {$title=AddSlashes ($_POST['title']);} else {$title="NULL";}
+
 if (isset($_POST['num_photos'])) {$num_photos=$_POST['num_photos'];}
 if (isset($_POST['task'])) {$task=$_POST['task'];} // else {$task="NULL";}
 if (isset($_POST['choice'])) {$choice=$_POST['choice'];} // else {$task="NULL";}
@@ -54,17 +65,32 @@ if (isset($_POST['new_nick'])) {$new_nick=$_POST['new_nick'];} else {$new_nick="
 if (isset($_POST['password'])) {$password=crypt($_POST['password'],'zzxzv');} else {$password="NULL";}
 if (isset($_POST['password_check'])) {$password_check=crypt($_POST['password_check'],'zzxzv');} else {$password_check="NULL";}
 if (isset($_POST['email'])) {$email=$_POST['email'];} else {$email="NULL";}
-if (isset($_POST['real_name'])) {$real_name=AddSlashes($_POST['real_name']);} else {$real_name="NULL";}
+
+if (!get_magic_quotes_gpc())
+   {
+   if (isset($_POST['real_name'])) {$real_name=AddSlashes($_POST['real_name']);} else {$real_name="NULL";}
+   } elseif (isset($_POST['real_name'])) {$real_name=$_POST['real_name'];} else {$real_name="NULL";}
+
 if (isset($_POST['level'])) {$level=$_POST['level'];} else {$level="NULL";}
 // Recieve functions arguments for the dbwa_edit_user and delete FUNCTION
 if (isset($_POST['id_user'])) {$id_user=$_POST['id_user'];} else {$id_user="NULL";}
 // Recive functions arguments for the dbwa_info FUNCTION
 if (isset($_GET['top_tab'])) {$top_tab=$_GET['top_tab'];} else {$top_tab="NULL";}
 if (isset($_GET['section_type'])) {$section_type=$_GET['section_type'];} else {$section_type="NULL";}
-if (isset($_POST['event_title'])) {$event_title=AddSlashes($_POST['event_title']);} else {$event_title="NULL";}
-if (isset($_POST['event_type'])) {$event_type=AddSlashes($_POST['event_type']);} else {$event_type="NULL";}
-if (isset($_POST['event_place'])) {$event_place=AddSlashes($_POST['event_place']);} else {$event_place="NULL";}
-if (isset($_POST['description'])) {$description=AddSlashes($_POST['description']);} else {$description="NULL";}
+
+if (!get_magic_quotes_gpc())
+   {
+   if (isset($_POST['event_title'])) {$event_title=AddSlashes($_POST['event_title']);} else {$event_title="NULL";}
+   if (isset($_POST['event_type'])) {$event_type=AddSlashes($_POST['event_type']);} else {$event_type="NULL";}
+   if (isset($_POST['event_place'])) {$event_place=AddSlashes($_POST['event_place']);} else {$event_place="NULL";}
+   if (isset($_POST['description'])) {$description=AddSlashes($_POST['description']);} else {$description="NULL";}
+   } else {
+          if (isset($_POST['event_title'])) {$event_title=$_POST['event_title'];} else {$event_title="NULL";}
+          if (isset($_POST['event_type'])) {$event_type=$_POST['event_type'];} else {$event_type="NULL";}
+          if (isset($_POST['event_place'])) {$event_place=$_POST['event_place'];} else {$event_place="NULL";}
+          if (isset($_POST['description'])) {$description=$_POST['description'];} else {$description="NULL";}
+          }
+
 if (isset($_POST['day'])) {$day=$_POST['day'];} else {$day="NULL";}
 if (isset($_POST['year'])) {$year=$_POST['year'];} else {$year="NULL";}
 if (isset($_POST['month'])) {$month=$_POST['month'];} else {$month="NULL";}
@@ -486,8 +512,8 @@ if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]))
           $sql = "DELETE FROM info_album WHERE id_info='$id_info' AND id_photo='".$id_photo["$i"]."'";
           mysql_query($sql, $db);
           // If the erased foto is the last foto for this new, then we need to put NO attached photos in db
-          $num_fotos=mysql_query ("SELECT filename FROM info_album WHERE id_info='$id_info'", $db);
-          if (mysql_num_rows ($num_photos))
+          $num_photos=mysql_query ("SELECT filename FROM info_album WHERE id_info='$id_info'", $db);
+          if (mysql_num_rows ($num_photos)==0)
              {
              mysql_query ("UPDATE info SET attached_photos='NO' WHERE id_info='$id_info'",$db);
              }
